import request from '@/utils/request'

// // 查询部门列表
// export async function listDept(query) {
//   let data = await request({
//     url: 'pc/videoType/info/list',
//     method: 'get',
//     params: {
//       ...query,
//       status: query.status == '1' ? '1' : '0'
//     }
//   })
//   if (data.code == 200) {
//     let tree = data.rows.filter(val => {
//       return val.pid == 0
//     })
//     tree = tree.map(f => {
//       f.children = data.rows.filter(val => {
//         return val.pid == f.id
//       })
//       return f
//     })
//     data.data = tree
//     console.log(data)
//     return data
//   } else {
//     return {}
//   }
// }

// 查询部门列表
export async function listDept(query) {
  let data = await request({
    url: 'pc/videoType/info/treeList',
    method: 'get'
  })
  if (!query.typeName) {
    return data
  } else {
    data.data = data.data.filter(val => {
      return (
        val.typeName.indexOf(query.typeName) !== -1 ||
        val.children.filter(val => {
          return val.typeName.indexOf(query.typeName) !== -1
        }).length > 0
      )
    })
    return data
  }
}

// // 查询部门列表（排除节点）
// export function listDeptExcludeChild(deptId) {
//   return request({
//     url: '/system/dept/list/exclude/' + deptId,
//     method: 'get'
//   })
// }

// 查询部门详细
export function getDept(deptId) {
  return request({
    url: 'pc/videoType/info/' + deptId,
    method: 'get'
  })
}

// 查询部门下拉树结构
export function treeselect() {
  return request({
    url: 'pc/videoType/info/treeList',
    method: 'get'
  })
}

// // 根据角色ID查询部门树结构
// export function roleDeptTreeselect(roleId) {
//   return request({
//     url: '/system/dept/roleDeptTreeselect/' + roleId,
//     method: 'get'
//   })
// }

// 新增部门
export function addDept(data) {
  return request({
    url: 'pc/videoType/info',
    method: 'post',
    data: data
  })
}

// 修改部门
export function updateDept(data) {
  return request({
    url: 'pc/videoType/info',
    method: 'put',
    data: data
  })
}

// 删除部门
export function delDept(deptId) {
  return request({
    url: 'pc/videoType/info/' + deptId,
    method: 'put'
  })
}
